@@ -39,7 +39,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "2.1.12"
+__version__ = "2.1.14"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FONA.git"
 
 FONA_DEFAULT_TIMEOUT_MS = 500  # TODO: Check this against arduino...
@@ -84,7 +84,7 @@ class FONA:
         self,
         uart: UART,
         rst: DigitalInOut,
-        ri: Optional[DigitalInOut] = None,
+        ri: Optional[DigitalInOut] = None,  # pylint: disable=invalid-name
         debug: bool = False,
     ) -> None:
         self._buf = b""  # shared buffer
